import { UntypedFormGroup } from '@angular/forms';
import { FormValidatorService } from '../core/form-validator.service';
/**
 * Interface used to ensure we have a consistent structure across our form components
 *
 * It also provides some abstraction of repeated code to reduce our codebase size
 *
 * @todo This should be moved to ngx-techlify-core
 *
 * Advantages of this abstract class
 * - Less code, less maintenance, less bugs
 * - more consistent code
 * - comments on more code
 * - save time, save energy
 */
export declare abstract class TechlifyFormComponentInterface {
    protected formValidatorService: FormValidatorService;
    form: UntypedFormGroup;
    errorMessages: any;
    constructor(formValidatorService: FormValidatorService);
    /**
     * Resets the value of a field in the HTML form
     *
     * @param event
     * @param field
     */
    resetFieldValue(event: any, field: string): void;
    /**
     * Retrieves the value of a field from the HTML form
     *
     * @param field
     * @returns
     */
    getFieldValue(field: string): any;
    /**
     * Method to evaluate form fields
     * */
    isFieldValid(field: string): any;
    /**
     * Method to find error in form fields
     * */
    getErrorMessage(field: string): any;
}
