import { ConfigService } from './config.service';
import * as i0 from "@angular/core";
export interface Credentials {
    user: any;
    token: any;
}
/**
 * Provides storage for authentication credentials.
 * The Credentials interface should be replaced with proper implementation.
 */
export declare class CredentialsService {
    private configService;
    private _credentials;
    constructor(configService: ConfigService);
    /**
     * Checks is the user is authenticated.
     * @return True if the user is authenticated.
     */
    get isAuthenticated(): boolean;
    /**
     * Gets the user credentials.
     * @return The user credentials or null if the user is not authenticated.
     */
    get credentials(): Credentials | null;
    /**
     * Sets the user credentials.
     * The credentials may be persisted across sessions by setting the `remember` parameter to true.
     * Otherwise, the credentials are only persisted for the current session.
     * @param credentials The user credentials.
     * @param remember True to remember credentials across sessions.
     */
    setCredentials(credentials?: Credentials, remember?: boolean): void;
    getAccessToken(): string | null;
    getExpiration(): string;
    getRefreshToken(): string;
    refresh(): CredentialsService;
    static ɵfac: i0.ɵɵFactoryDeclaration<CredentialsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CredentialsService>;
}
